# bingpaper
[![PyPI version](https://img.shields.io/pypi/v/bingpaper.svg)](https://pypi.python.org/pypi/bingpaper)
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fguptarohit%2Fbingpaper.svg?type=shield)](https://app.fossa.io/projects/git%2Bgithub.com%2Fguptarohit%2Fbingpaper?ref=badge_shield)
[![License](https://img.shields.io/pypi/l/bingpaper.svg)](https://github.com/guptarohit/bingpaper/blob/master/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

This program automatically sets [Bing](http://www.bing.com/)'s _photo of the day_ as your desktop's wallpaper. Available for Windows, macOS & Linux.

Installation
------------

```
$ pip install bingpaper
```

to install from the latest source use following command

```
$ pip install git+git://github.com/guptarohit/bingpaper.git
```

Usage
-----

To update the wallpaper simply run:
```
$ bingpaper
```

Contributing
------------

Feel free to make a pull request! :octocat:

License
-------
[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fguptarohit%2Fbingpaper.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fguptarohit%2Fbingpaper?ref=badge_large)